/*
 * QtTapioca, the Tapioca Qt4 Client Library
 * Copyright (C) 2006 by INdT
 *  @author Abner Jose de Faria Silva <abner.silva@indt.org.br>
 *  @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef QTTAPIOCA_CONTACT_H
#define QTTAPIOCA_CONTACT_H

#include <QtCore/QObject>
#include <QtCore/QString>
#include <QtTapioca/ContactBase>

#include <QtTelepathy/Client/Connection>
#include <QtTelepathy/Client/ConnectionAvatarsInterface>
#include <QtTelepathy/Client/ConnectionPresenceInterface>
#include <QtTelepathy/Client/ConnectionAliasingInterface>
#include <QtTelepathy/Client/ConnectionCapabilitiesInterface>

namespace QtTapioca {

class ContactPrivate;

class Contact: public ContactBase {
    Q_OBJECT
    Q_DECLARE_PRIVATE(Contact)
    Q_ENUMS(SubscriptionStatus)

public:
    enum SubscriptionStatus {
        Current = 0,
        LocalPending,
        RemotePending
    };

    ~Contact();

    SubscriptionStatus subscriptionStatus() const;
    bool isBlocked() const;

Q_SIGNALS:
    void subscriptionStatusChanged(QtTapioca::Contact::SubscriptionStatus status);

private Q_SLOTS:

private:
    friend class ContactList;

    Contact(org::freedesktop::Telepathy::Connection *telepathyConn,
            org::freedesktop::Telepathy::ConnectionAvatarsInterface *telepathyIAvatar,
            org::freedesktop::Telepathy::ConnectionPresenceInterface *telepathyIPresence,
            org::freedesktop::Telepathy::ConnectionAliasingInterface *telepathyIAliasing,
            org::freedesktop::Telepathy::ConnectionCapabilitiesInterface *telepathyICapabilities,
            Handle *handle,
            SubscriptionStatus status,
            QObject *parent = 0);
    void setSubscriptionStatus(SubscriptionStatus status);

    ContactPrivate *d;
};

} // namespace

#endif

